@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class LogInFile : public QObject
     Q_OBJECT
 public:
     explicit LogInFile(QObject *parent = nullptr);
-    ~LogInFile();
+    ~LogInFile() override;
 
     Q_REQUIRED_RESULT QString fileName() const;
     void setFileName(const QString &fileName);
